@@ -794,6 +794,18 @@ SEXP ps__boot_time() {
   return ScalarReal(psll_linux_boot_time);
 }
 
+SEXP ps__cpu_count_logical() {
+  int n = sysconf(_SC_NPROCESSORS_ONLN);
+  if (n >= 1) return ScalarInteger(n);
+  return(ScalarInteger(NA_INTEGER));
+}
+
+/* This is not used, because it is much easier to parse this file from R */
+
+SEXP ps__cpu_count_physical() {
+  return R_NilValue;
+}
+
 static int psl__linux_match_environ(SEXP r_marker, SEXP r_pid) {
   const char *marker = CHAR(STRING_ELT(r_marker, 0));
   pid_t pid = INTEGER(r_pid)[0];
