@@ -1,7 +1,7 @@
 library(testthat)
 library(ps)
 
-if (ps::ps_is_supported()) {
+if (ps::ps_is_supported() && Sys.getenv("R_COVR", "") != "true") {
   reporter <- ps::CleanupReporter(testthat::SummaryReporter)$new()
 } else {
   ## ps does not support this platform
